@@ -14,15 +14,14 @@ from addict import Dict
 from appdirs import AppDirs
 from rich import print
 
-from kodexa.taxonomy.taxonomy import Taxonomy
 from kodexa.connectors import get_source
 from kodexa.connectors.connectors import get_caller_dir, FolderConnector
-from kodexa.model import Document
-from kodexa.model.model import RemoteStore
+from kodexa.model import Document, DocumentStore
 from kodexa.pipeline import PipelineContext, Pipeline, PipelineStatistics
 from kodexa.stores import RemoteDocumentStore
 from kodexa.stores import TableDataStore
 from kodexa.stores.stores import LocalDocumentStore
+from kodexa.taxonomy.taxonomy import Taxonomy
 from kodexa.workflow.workflow import Workflow
 
 logger = logging.getLogger('kodexa.platform')
@@ -66,9 +65,9 @@ class PipelineMetadataBuilder:
 
         for pipeline_store in self.pipeline.stores:
 
-            if isinstance(pipeline_store.store, RemoteStore):
+            if isinstance(pipeline_store.store, RemoteDocumentStore):
                 pipeline_metadata.metadata.stores.append(
-                    {"name": pipeline_store.name, "ref": pipeline_store.store.get_ref()})
+                    {"name": pipeline_store.name, "ref": pipeline_store.store.get_ref(), "storeType": "DOCUMENT"})
             else:
                 raise Exception("Pipeline refers to a non-remote store, deployment of local stores is not supported")
 
@@ -381,7 +380,7 @@ class KodexaPlatform:
             raise Exception("Unable to list objects")
 
     @staticmethod
-    def undeploy(object_type:str, ref: str):
+    def undeploy(object_type: str, ref: str):
 
         object_type, object_type_metadata = resolve_object_type(object_type)
 
@@ -483,8 +482,8 @@ class KodexaPlatform:
     @classmethod
     def get_server_info(cls):
         r = requests.get(f"{KodexaPlatform.get_url()}/api",
-                            headers={"x-access-token": KodexaPlatform.get_access_token(),
-                                     "content-type": "application/json"})
+                         headers={"x-access-token": KodexaPlatform.get_access_token(),
+                                  "content-type": "application/json"})
         if r.status_code == 401:
             raise Exception("Your access token was not authorized")
         elif r.status_code == 200:
@@ -505,6 +504,7 @@ class RemoteSession:
         self.cloud_session = None
 
     def get_action_metadata(self, ref):
+        logger.debug(f"Downloading metadata for action {ref}")
         r = requests.get(f"{KodexaPlatform.get_url()}/api/actions/{ref}",
                          headers={"x-access-token": KodexaPlatform.get_access_token()})
         if r.status_code == 401:
@@ -530,7 +530,7 @@ class RemoteSession:
     def execution_action(self, document, options, attach_source):
         files = {}
         if attach_source:
-            logger.info("Attaching source")
+            logger.debug("Attaching source to call")
             files["file"] = get_source(document)
             files["file_document"] = document.to_msgpack()
         else:
@@ -745,6 +745,19 @@ class RemotePipeline:
         """
         return RemotePipeline(slug, FolderConnector(folder_path, filename_filter, recursive, relative, caller_path))
 
+    def to_store(self, document_store: DocumentStore, processing_mode: str = "update"):
+        """
+        Allows you to provide the sink store easily
+
+        This will wrap the store in a document store sink
+
+        :param document_store: document store to use
+        :param processing_mode: the processing mode (update or new)
+        :return: the pipeline
+        """
+        from kodexa.sinks import DocumentStoreSink
+        self.set_sink(DocumentStoreSink(document_store))
+        return self
 
 class RemoteAction:
     """
