@@ -459,10 +459,14 @@ class LocalDocumentStore(DocumentStore):
 
 class RemoteDocumentStore(DocumentStore, RemoteStore):
 
-    def __init__(self, ref: str):
+    def __init__(self, ref: str, query: str = "*"):
         self.ref: str = ref
-        self.objects: List[Dict] = []
+        self.objects: Optional[List[Dict]] = None
         self.page = 1
+        self.query_string: str = query
+
+    def get_name(self):
+        return "document-store"
 
     def to_dict(self):
         return {
@@ -473,8 +477,10 @@ class RemoteDocumentStore(DocumentStore, RemoteStore):
     def get(self, document_id: str) -> Optional[Document]:
         from kodexa import KodexaPlatform
 
+        url = f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/contents/{document_id}/content"
+        logger.info(f"Downloading document from {url}")
         doc = requests.get(
-            f"{KodexaPlatform.get_url()}/api/stores/{self.ref}/contents/{document_id}",
+            url,
             headers={"x-access-token": KodexaPlatform.get_access_token()})
         if doc.status_code == 200:
             return Document.from_msgpack(doc.content)
@@ -487,8 +493,11 @@ class RemoteDocumentStore(DocumentStore, RemoteStore):
     def get_source(self, document_id: str):
         from kodexa import KodexaPlatform
 
+        url = f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/contents/{document_id}/content"
+        logger.info(f"Downloading source from {url}")
+
         doc = requests.get(
-            f"{KodexaPlatform.get_url()}/api/stores/{self.ref}/contents/{document_id}",
+            url,
             headers={"x-access-token": KodexaPlatform.get_access_token()})
 
         if doc.status_code == 200:
@@ -588,20 +597,19 @@ class RemoteDocumentStore(DocumentStore, RemoteStore):
         return self
 
     def __next__(self):
+
+        if self.objects is None:
+            self.objects = self.query_objects(self.query_string)
+
         if len(self.objects) == 0:
             raise StopIteration
         else:
             content_object = self.objects.pop(0)
 
-            if content_object['content_type'] == "Document":
+            if content_object['content_type'] == "DOCUMENT":
                 return self.get(content_object['id'])
-            else:
 
-                # TODO we need the connector?
-                document = Document()
-                document.source.connector = self.get_name()
-                document.source.original_path = f"{self.ref}/contents/{content_object['id']}"
-                return document
+            raise StopIteration
 
 
 class DocumentReference:
